@@ -28,7 +28,7 @@ BEGIN {
     }
 }
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 sub _ANYPROCESS                    { return -1 }
 sub _COMMAND                       { return 0 }
@@ -548,12 +548,12 @@ sub _setup_local_connection_to_firefox {
         }
     }
     $self->_reap();
-    if ( ( kill 0, $self->_pid() ) && ($socket) ) {
+    if ( ( $self->alive() ) && ($socket) ) {
     }
     else {
         my $error_message =
           $self->error_message() ? $self->error_message() : q[];
-        Carp::croak( $error_message );
+        Carp::croak($error_message);
     }
     return $socket;
 }
@@ -1795,7 +1795,7 @@ Firefox::Marionette - Automate the Firefox browser with the Marionette protocol
 
 =head1 VERSION
 
-Version 0.26
+Version 0.27
 
 =head1 SYNOPSIS
 
